@@ -8,32 +8,42 @@ work with asyncio.
 
 import asyncio
 import logging
-import sys
+from typing import (
+    Any,
+    Awaitable,
+    Callable,
+    Optional,
+    cast,
+)
 from xmlrpc import client as xmlrpc
 
 import httpx
 
 __ALL__ = ["ServerProxy", "Fault", "ProtocolError"]
 
+RPCResult = Any
+RPCParameters = Any
+
 # you don't have to import xmlrpc.client from your code
 Fault = xmlrpc.Fault
 ProtocolError = xmlrpc.ProtocolError
 
 log = logging.getLogger(__name__)
-PY35 = sys.version_info >= (3, 5)
 
 
 class _Method:
     # some magic to bind an XML-RPC method to an RPC server.
     # supports "nested" methods (e.g. examples.getStateName)
-    def __init__(self, send, name):
+    def __init__(
+        self, send: Callable[[str, RPCParameters], Awaitable[RPCResult]], name: str
+    ) -> None:
         self.__send = send
         self.__name = name
 
-    def __getattr__(self, name):
+    def __getattr__(self, name: str) -> "_Method":
         return _Method(self.__send, "%s.%s" % (self.__name, name))
 
-    async def __call__(self, *args):
+    async def __call__(self, *args: RPCParameters) -> RPCResult:
         ret = await self.__send(self.__name, args)
         return ret
 
@@ -45,22 +55,28 @@ class AioTransport(xmlrpc.Transport):
 
     def __init__(
         self,
-        session,
-        use_https,
+        session: httpx.AsyncClient,
+        use_https: bool,
         *,
-        use_datetime=False,
-        use_builtin_types=False,
-        auth=None,
-        timeout=None,
+        use_datetime: bool = False,
+        use_builtin_types: bool = False,
+        auth: Optional[httpx._types.AuthTypes] = None,
+        timeout: Optional[httpx._types.TimeoutTypes] = None,
     ):
         super().__init__(use_datetime, use_builtin_types)
         self.use_https = use_https
         self._session = session
 
-        self.auth = auth
+        self.auth = auth or httpx.USE_CLIENT_DEFAULT
         self.timeout = timeout
 
-    async def request(self, host, handler, request_body, verbose=False):
+    async def request(  # type: ignore
+        self,
+        host: str,
+        handler: str,
+        request_body: dict[str, Any],
+        verbose: bool = False,
+    ) -> RPCResult:
         """
         Send the XML-RPC request, return the response.
         This method is a coroutine.
@@ -80,7 +96,9 @@ class AioTransport(xmlrpc.Transport):
                     url,
                     response.status_code,
                     body,
-                    response.headers,
+                    # response.headers is a case insensitive dict from httpx,
+                    # the ProtocolError is typed as simple dict
+                    cast(dict[str, str], response.headers),
                 )
         except asyncio.CancelledError:
             raise
@@ -90,7 +108,7 @@ class AioTransport(xmlrpc.Transport):
             log.error("Unexpected error", exc_info=True)
             if response is not None:
                 errcode = response.status_code
-                headers = response.headers
+                headers = cast(dict[str, str], response.headers)  # coverage: ignore
             else:
                 errcode = 0
                 headers = {}
@@ -98,7 +116,10 @@ class AioTransport(xmlrpc.Transport):
             raise ProtocolError(url, errcode, str(exc), headers)
         return self.parse_response(body)
 
-    def parse_response(self, body):
+    def parse_response(  # type: ignore
+        self,
+        body: str,
+    ) -> RPCResult:
         """
         Parse the xmlrpc response.
         """
@@ -107,13 +128,13 @@ class AioTransport(xmlrpc.Transport):
         p.close()
         return u.close()
 
-    def _build_url(self, host, handler):
+    def _build_url(self, host: str, handler: str) -> str:
         """
         Build a url for our request based on the host, handler and use_http
         property
         """
         scheme = "https" if self.use_https else "http"
-        return "%s://%s%s" % (scheme, host, handler)
+        return f"{scheme}://{host}{handler}"
 
 
 class ServerProxy(xmlrpc.ServerProxy):
@@ -123,20 +144,19 @@ class ServerProxy(xmlrpc.ServerProxy):
 
     def __init__(
         self,
-        uri,
-        encoding=None,
-        verbose=False,
-        allow_none=False,
-        use_datetime=False,
-        use_builtin_types=False,
-        auth=None,
+        uri: str,
+        encoding: Optional[str] = None,
+        verbose: bool = False,
+        allow_none: bool = False,
+        use_datetime: bool = False,
+        use_builtin_types: bool = False,
+        auth: Optional[httpx._types.AuthTypes] = None,
         *,
-        headers=None,
-        context=None,
-        timeout=5.0,
-        session=None,
-    ):
-
+        headers: Optional[dict[str, Any]] = None,
+        context: Optional[httpx._types.VerifyTypes] = None,
+        timeout: httpx._types.TimeoutTypes = 5.0,
+        session: Optional[httpx.AsyncClient] = None,
+    ) -> None:
         if not headers:
             headers = {
                 "User-Agent": "python/aioxmlrpc",
@@ -165,20 +185,24 @@ class ServerProxy(xmlrpc.ServerProxy):
             use_builtin_types,
         )
 
-    async def __request(self, methodname, params):
+    async def __request(  # type: ignore
+        self,
+        methodname: str,
+        params: RPCParameters,
+    ) -> RPCResult:
         # call a method on the remote server
         request = xmlrpc.dumps(
             params, methodname, encoding=self.__encoding, allow_none=self.__allow_none
         ).encode(self.__encoding)
 
-        response = await self.__transport.request(
+        response = await self.__transport.request(  # type: ignore
             self.__host, self.__handler, request, verbose=self.__verbose
         )
 
-        if len(response) == 1:
+        if len(response) == 1:  # type: ignore
             response = response[0]
 
         return response
 
-    def __getattr__(self, name):
+    def __getattr__(self, name: str) -> _Method:  # type: ignore
         return _Method(self.__request, name)
